--[[
  Lokasenna_GUI 2.0 previewgrid
  
  -- Tabs and layer sets
  -- Accessing elements' parameters

]]--

-----DEBUG CONTROL--------------------------------------------------------------

debug_output = true -- true/false --display debug messages in the console

-----DISPLAY CONSOLE MESSAGE----------------------------------------------------

-- Display a message in the console for debugging, message can be a number variable
-- or a string but not mixed. No line feed character is added.
function Msg(value)
  --returns nothing

  if debug_output then --check if flag is set true (at the start of this script)
    reaper.ShowConsoleMsg(tostring(value) )
  end
end


local dm, _ = debug_mode
local function Msg(str)
  reaper.ShowConsoleMsg(tostring(str).."\n")
end

local info = debug.getinfo(1,'S');
script_path = info.source:match[[^@?(.*[\/])[^\/]-$]]


-- The Core library must be loaded prior to anything else
--[[
--------------------------------
 --REATRAK LOCAL GUI LIBRARY start
--------------------------------
local lib_path = script_path --reaper.GetExtState("Lokasenna_GUI", "lib_path_v2")
if not lib_path or lib_path == "" then
    reaper.MB("Couldn't load the Lokasenna_GUI library. Please run 'Script: Set Lokasenna_GUI v2 library path.lua' in your Action List.", "Whoops!", 0)
    return
end

loadfile(script_path .. "ReaTrak_Core.lua")()

GUI.req(script_path .. "ReaTrak_Classes/Class - Label.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Knob.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Tabs.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Slider.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Button.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Menubox.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Textbox.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Frame.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Options.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Window.lua")()

--------------------------------
 --REATRAK LOCAL GUI LIBRARY end
--------------------------------

--]]
--------------------------------
 --LOKASENNA GUI LIBRARY start
--------------------------------

local lib_path = reaper.GetExtState("Lokasenna_GUI", "lib_path_v2")
if not lib_path or lib_path == "" then
    reaper.MB("Couldn't load the Lokasenna_GUI library. Please run 'Script: Set Lokasenna_GUI v2 library path.lua' in your Action List.", "Whoops!", 0)
    return
end
loadfile(lib_path .. "Core.lua")()

GUI.req("Classes/Class - Label.lua")()
GUI.req("Classes/Class - Knob.lua")()
GUI.req("Classes/Class - Tabs.lua")()
GUI.req("Classes/Class - Slider.lua")()
GUI.req("Classes/Class - Button.lua")()
GUI.req("Classes/Class - Menubox.lua")()
GUI.req("Classes/Class - Textbox.lua")()
GUI.req("Classes/Class - Frame.lua")()
GUI.req("Classes/Class - Options.lua")()
GUI.req("Classes/Class - Window.lua")()

--------------------------------
 --LOKASENNA GUI LIBRARY end
--------------------------------
if missing_lib then return 0 end



--GUI Size


GUI.name = "Ripple Edit"
GUI.x, GUI.y, GUI.w, GUI.h = 0, 0, 215, 80
GUI.anchor, GUI.corner = "mouse", "C"


 
    
   
  local function btn_click() 
  
  --reaper.ShowMessageBox("Yay, you clicked a button. Now what?", "<(^^<)", 0)
  
  local tab_num = GUI.Val("tabs")
  Msg("Displaying values for tab "..tostring(tab_num))
  
  -- The '+ 2' here is just to translate from a tab number to its' 
  -- associated z layer. More complicated scripts would have to 
  -- actually access GUI.elms.tabs.z_sets[tab_num] and iterate over
  -- the table's contents (see the call to GUI.elms.tabs:update_sets
  -- below)
  for k, v in pairs(GUI.elms_list[tab_num + 2]) do
    
    local val = GUI.Val(v)
    if type(val) == "table" then
      local str = ""
      for i = 1, #val do
        str = str..", "..tostring(val[i])
      end
      val = string.sub(str, 3)
    end
    Msg("\t"
      ..tostring(v)
      .."\t\t"
      ..tostring(val)
       )
    
  end
    
  
end 


--[[     

  New elements are created by:
  
  GUI.New(name, class, params)
  
  and can then have their parameters accessed via:
  
  GUI.elms.name.param
  
  ex:
  
  GUI.New("my_new_label", "Label", 1, 32, 32, "This is my label")
  GUI.elms.my_new_label.color = "magenta"
  GUI.elms.my_new_label.font = 1
  
  
    Classes and parameters
  
  Button          name,      z,      x,      y,      w,      h, caption, func[, ...]
  Checklist     name,      z,      x,      y,      w,      h, caption, opts[, dir, pad]
  Frame          name,      z,      x,      y,      w,      h[, shadow, fill, color, round]
  Knob          name,      z,      x,      y,      w,      caption, min, max, steps, default[, vals]     
  Label          name,      z,      x,      y,          caption[, shadow, font, color, bg]
  Menubox          name,      z,      x,      y,      w,      h, caption, opts
  Radio          name,      z,      x,      y,      w,      h, caption, opts[, dir, pad]
  Slider          name,      z,      x,      y,      w,      caption, min, max, steps, handles[, dir]
  Tabs          name,      z,      x,      y,           tab_w, tab_h, opts[, pad]
  Textbox          name,      z,      x,      y,      w,      h[, caption, pad]

  
]]--

-- Button Colors  = {r, g, b, transparency}

GUI.colors["count_in"] = {255, 124, 192, 255}
GUI.colors["intro_post_fill"] = {119, 17, 174, 255}
GUI.colors["intro"] = {159, 22, 232, 255}
GUI.colors["intro_fill"] = {183, 128, 237, 255}
GUI.colors["verse_post_fill"] = {17, 39, 174, 255}
GUI.colors["verse"] = {55, 118, 235, 255}
GUI.colors["verse_fill"] = {113, 190, 241, 255}
GUI.colors["verse_ending"] = {151, 208, 245, 255}
GUI.colors["bridge_post_fill"] = {206, 105, 20, 255}
GUI.colors["bridge"] = {234, 133, 48, 255}
GUI.colors["bridge_fill"] = {239, 164, 100, 255}
GUI.colors["pre_chorus_post_fill"] = {206, 179, 20, 255}
GUI.colors["pre_chorus"] = {234, 208, 48, 255}
GUI.colors["pre_chorus_fill"] = {244, 231, 151, 255}
GUI.colors["chorus_post_fill"] = {11, 116, 39, 255}
GUI.colors["chorus"] = {17, 174, 59, 255}
GUI.colors["chorus_fill"] = {80, 237, 123, 255}
GUI.colors["chorus_ending"] = {158, 254, 182, 255}
GUI.colors["play_anywhere"] = {228, 26, 39, 250}
GUI.colors["drum_riff"] = {115, 23, 17, 255}
GUI.colors["hold"] = {191, 191, 191, 255}
GUI.colors["shot"] = {127, 127, 127, 255}
GUI.colors["rest"] = {0, 0, 0, 255}

--Text Colors

GUI.colors["btn_txt1"] = {255, 255, 255, 255} --white
GUI.colors["btn_txt2"] = {155, 155, 155, 255} --gray
GUI.colors["btn_txt3"] = {0, 0, 0, 255} --black


--Tabs

GUI.New("tabs",      "Tabs",           1, 0, 0, 25, 20, "Tools", 60)
--GUI.New("tab_bg",     "Frame",          2, 0, 0, 600, 20, true, true, "elm_bg", 1)
GUI.elms.tabs.col_txt = "chorus_fill"

-- Telling the tabs which z layers to display
-- See Classes/Tabs.lua for more detail
GUI.elms.tabs:update_sets(
  --  Tab
  --               Layers
  {     [1] =     {3,6},
    [2] =     {2,4,7}, --Include layer 2,6 on Tab 2 Chord Root Radio and Insert Root Note Button
    [3] =     {2,5,6}, --Include layer 2 on Tab 3 Chord Root Radio and Insert Root Note Button
    [4] =     {6},
    [5] =     {7},
    [6] =     {8},
    [7] =     {9},
    [8] =     {10},
    [9] =     {11},
    [10] =     {12},
    [11] =     {13},
    [12] =     {14},
    [13] =     {15},
    [14] =     {16},
    [15] =     {17},
    [16] =     {18},
    [17] =     {19},
    [18] =     {20},
    [19] =     {21},
    [20] =     {22},
    
  }
)

-- Notice that layers 1 and 2 aren't assigned to a tab; this leaves them visible
-- all the time.

-----------------------------------------------------------------------------------
--Tools Buttons Tab 1 (layer 3)
-----------------------------------------------------------------------------------



--ReaTrak Actions Functions



    
function btn_click_show_chords_in_items()
    reaper.Main_OnCommand(1155, 0) -- Options: Cycle ripple editing mode
    
    update_show_chords_in_items()
end 
    

--ReaTrak Actions
-- Button Position Adjustment add e.g x = -10 or x = 0 or x = 10
x2 = 0
y2 = 0 

--GUI.New("btn_frm",     "Frame",          3, 0, 156+y2, GUI.w, 4, true, true) 

--GUI.New("lb_rea_act",      "Label",           3, 20+x2, 25+y2, "Ripple Edit", true, 1)

--GUI.New("act_help_btn",      "Button",           3, 215+x2, 180+y2, 40, 17, "HELP", btn_click_act_help)
--GUI.elms.act_help_btn.col_txt = "btn_txt1"
--GUI.elms.act_help_btn.col_fill = "green"
--GUI.elms.act_help_btn.font = ("version")





function update_show_chords_in_items() 
    
--Delete old buttons before updating
--Msg(reaper.GetToggleCommandState(1155))  

   if reaper.GetToggleCommandState(1155) == 1 then onstate = "black" textstate = "red" -- Options: Cycle ripple editing mode
      GUI.elms.show_chords_in_items_btn:ondelete()
      GUI.New("show_chords_in_items_btn",      "Button",           3, 40+x2, 30+y2, 135, 20, "Ripple Edit On", btn_click_show_chords_in_items)
      GUI.elms.show_chords_in_items_btn.col_txt = textstate
      GUI.elms.show_chords_in_items_btn.col_fill = onstate 
      
      GUI.elms.show_chords_in_items_btn:init()
   end
   if reaper.GetToggleCommandState(1155) == 0 then
   onstate = "gray" textstate = "yellow"
   
   GUI.elms.show_chords_in_items_btn:ondelete()
 
   GUI.New("show_chords_in_items_btn",      "Button",           3, 40+x2, 30+y2, 135, 20, "Ripple Edit Off", btn_click_show_chords_in_items)
   GUI.elms.show_chords_in_items_btn.col_txt = textstate
   GUI.elms.show_chords_in_items_btn.col_fill = onstate    

   GUI.elms.show_chords_in_items_btn:init()    
   end
end



   if reaper.GetToggleCommandState(1155) == 1 then onstate = "black" textstate = "red"
   
      GUI.New("show_chords_in_items_btn",      "Button",           3, 40+x2, 30+y2, 135, 20, "Ripple Edit On", btn_click_show_chords_in_items)
      GUI.elms.show_chords_in_items_btn.col_txt = textstate
      GUI.elms.show_chords_in_items_btn.col_fill = onstate
   else
      onstate = "gray" textstate = "yellow"
      GUI.New("show_chords_in_items_btn",      "Button",           3, 40+x2, 30+y2, 135, 20, "Ripple Edit Off", btn_click_show_chords_in_items)
      GUI.elms.show_chords_in_items_btn.col_txt = textstate
      GUI.elms.show_chords_in_items_btn.col_fill = onstate
   end

--Actions Row Top
 
--GUI.New("show_chords_in_items_btn",      "Button",           3, 70+x2, 30+y2, 135, 20, "Ripple Edit", btn_click_show_chords_in_items)
--GUI.elms.show_chords_in_items_btn.col_txt = textstate
--GUI.elms.show_chords_in_items_btn.col_fill = onstate
    













-- This will be run on every update loop of the GUI script; anything you would put
-- inside a reaper.defer() loop should go here. (The function name doesn't matter)
local function Main()

    if reaper.GetToggleCommandState(1155) == 1 then
       xpos, ypos = reaper.GetMousePosition()
       reaper.TrackCtl_SetToolTip("RE", xpos+11, ypos+6, true)
    end   
    
    --scale = GUI.elms.scale_choice.optarray[ GUI.Val("scale_choice") ]
    --inkey = GUI.elms.key_choice.optarray[ GUI.Val("key_choice") ]
  
  
  --GUI.New("lb_scale",      "Label",           4, 60, 20, scale, true, 1)    
  -- Prevent the user from resizing the window
  --if GUI.resized then
    
    -- If the window's size has been changed, reopen it
    -- at the current position with the size we specified
    --local __,x,y,w,h = gfx.dock(-1,0,0,0,0)
    --gfx.quit()
    --gfx.init(GUI.name, GUI.w, GUI.h, 0, x, y)
    --GUI.redraw_z[0] = true
  --update_buttons()             
    
   end


GUI.Init()

-- Tell the GUI library to run Main on each update loop
-- Individual elements are updated first, then GUI.func is run, then the GUI is redrawn
GUI.func = Main

-- How often (in seconds) to run GUI.func. 0 = every loop.
GUI.freq = 0


GUI.Main()

